@@ -1241,10 +1241,41 @@ def tool() -> None:
     description = (
         f"{colorama.Style.BRIGHT}{colorama.Fore.GREEN}PyFunceble"
         f"{colorama.Style.RESET_ALL} - "
-        "The tool to check the availability or syntax of domain, IP or URL."
+        "The tool to check the availability or syntax of domain, IP or URL.\n\n"
+        f"{colorama.Style.BRIGHT}Note:{colorama.Style.RESET_ALL}\n"
+        "    All arguments listed bellow acts a switch to your configuration file-s.\n"
+        "    This means that if (e.g.) 'file_generation.no_file' is set to 'true' "
+        "its value\n"
+        "    will be switch to 'false' at the runtime if the '--no-files' argument is "
+        "being used.\n"
+        "    Meaning that output files will be generated."
     )
 
     our_epilog = (
+        f"{colorama.Style.BRIGHT}Examples:{colorama.Style.RESET_ALL}\n\n"
+        "    Check the availability of 'example.com'.\n"
+        "       $ pyfunceble -d example.com\n\n"
+        "    Check the availability of 'example.com' with a simple (stdout) output.\n"
+        "       $ pyfunceble -s -d example.com\n\n"
+        "    Check the availability of 'example.com' with extended (stdout) output.\n"
+        "       $ pyfunceble -a -d example.com\n\n"
+        "    Check the availability of 'example.com' and 'example.org'.\n"
+        "       $ pyfunceble -d example.com example.org\n\n"
+        "    Check the availability of 'https://example.com'.\n"
+        "       $ pyfunceble -u https://example.com\n\n"
+        "    Check the availability of 'https://example.com' and "
+        "'https://example.org'.\n"
+        "       $ pyfunceble -u https://example.com https://example.com\n\n"
+        "    Check the syntax of 'example.com'.\n"
+        "       $ pyfunceble --syntax -d example.com\n\n"
+        "    Check the reputation of 'example.com'.\n"
+        "       $ pyfunceble --reputation -d example.com\n\n"
+        "    Check the availability of all subjects in the 'myhosts' file.\n"
+        "       $ pyfunceble -f myhosts\n\n"
+        "    Check the availability of all subjects in the 'myhosts' and 'yourhosts' "
+        "files.\n"
+        "       $ pyfunceble -f myhosts yourhosts\n\n"
+        "\n\n"
         f"{colorama.Style.BRIGHT}{colorama.Fore.YELLOW}For an in-depth usage, "
         "explanation and examples of the arguments,\n"
         f"you should read the documentation at{colorama.Fore.GREEN} "
