@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2021 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -277,7 +277,12 @@ class DNSQueryTool:
                 except ValueError:
                     return dns.name.from_text(self.subject)
             return dns.name.from_text(self.subject)
-        except (dns.name.LabelTooLong, dns.name.EmptyLabel, dns.name.BadEscape):
+        except (
+            dns.name.LabelTooLong,
+            dns.name.EmptyLabel,
+            dns.name.BadEscape,
+            dns.name.NameTooLong,
+        ):
             return None
 
     @property
